@@ -66,7 +66,7 @@ elements) in a locked format. All other formatting will remain the same and the
 
 =head1 AUTHOR
 
-Rob Kinyon (rkinyon@columbus.rr.com)
+Rob Kinyon (rob.kinyon@gmail.com)
 
 =head1 SEE ALSO
 
