@@ -52,7 +52,9 @@ BEGIN {
     FORMAT
     FORMULA
     IF
+    HIDDEN
     ITALIC
+    LOCKED
     OUTLINE
     LOOP
     BACKREF
